<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package RainbowNews
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?> >

<?php
if( get_theme_mod( 'rainbownews_activate_loader' ) == '1' ) : ?>
<div class="pageloader">
	<div class="spinner">
		<div class="rect1"></div>
		<div class="rect2"></div>
		<div class="rect3"></div>
		<div class="rect4"></div>
		<div class="rect5"></div>
	</div>
</div>
<?php endif; ?>

<div id="page" class="site">
    <a class="skip-link screen-reader-text" href="#main"><?php esc_html_e('Skip to content', 'rainbownews'); ?></a>
    <?php
    $header_image = get_header_image();
    if( ! empty( $header_image ) ) {
        ?>
		<div class="nnc-header-image">
			<img src="<?php echo esc_url( $header_image ); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>"
				 alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
		</div>
        <?php
    }
    ?>


    <?php if (get_theme_mod('rainbownews_top_bar_activate') == '1') : ?>

        <div class="nnc-top-header">
            <div class="nnc-container">
                <?php if (has_nav_menu('top-menu')) : ?>
                    <div class="nnc-top-menu">
                        <?php wp_nav_menu(array('theme_location' => 'top-menu', 'menu_id' => 'top-menu')); ?>
                    </div>
                <?php endif; ?>

                <?php if (has_nav_menu('social-icon')) : ?>
                    <div class="nnc-social">
                        <?php wp_nav_menu(array('theme_location' => 'social-icon', 'menu_id' => 'social-menu')); ?>
                    </div>
                <?php endif; ?>

                <?php if (get_theme_mod('rainbownews_top_bar_date') == '1') : ?>

                    <div class="nnc-time">
                        <i class="fa fa-calendar"></i> <?php echo date_i18n('l, F j, Y', time()); ?>
                    </div>

                <?php endif; ?>

            </div>
        </div>

    <?php endif; ?>
</div>

<header id="masthead" class="site-header" role="banner">


    <div class="nnc-logo-bar">
        <div class="nnc-container">
            <div class="site-branding">

                <?php if ( (get_theme_mod('rainbownews_header_logo_placement', 'header_text_only') == 'show_both'
                        || get_theme_mod('rainbownews_header_logo_placement', 'header_text_only') == 'header_logo_only')
                    && has_custom_logo()
                ) : ?>

                    <div class="nnc-logo-img">
                        <?php the_custom_logo(); ?>
                    </div>

                <?php endif; ?>
                <?php
                $logo_only =get_theme_mod( 'rainbownews_header_logo_placement', 'header_text_only' );
                if($logo_only != 'header_logo_only'){ ?>
                    <div class="nnc-logo">
                    <?php
                    if (is_front_page() && is_home()) : ?>
                        <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                                                  rel="home"><?php bloginfo('name'); ?></a></h1>
                    <?php else : ?>
                        <p class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"
                                                 rel="home"><?php bloginfo('name'); ?></a></p>
                        <?php
                    endif;

                    $description = get_bloginfo('description', 'display');
                    if ($description || is_customize_preview()) : ?>
                        <p class="site-description"><?php echo esc_html($description); /* WPCS: xss ok. */ ?></p>
                        <?php
                    endif; ?>
                </div>
                <?php }?>
            </div><!-- .site-branding -->

            <!-- widget advertisement -->
            <?php
            if (is_active_sidebar('rainbownews_advertisement')) {
                dynamic_sidebar('rainbownews_advertisement');
            }
            ?>

        </div>
    </div>


    <div class="nnc-nav">
        <div class="nnc-container">
            <div class="nnc-main-navigation">
                <?php wp_nav_menu(array('theme_location' => 'primary', 'menu_id' => 'primary-menu')); ?>
            </div
        </div>
        <div class="nnc-resp-menu">
            <div class="nnc-container">
                <i class="fa fa-navicon"></i> MENU
            </div>
        </div>
        <div class="nnc-resp-navigation">
            <?php wp_nav_menu(array('theme_location' => 'primary', 'menu_id' => 'primary-menu')); ?>
        </div
    </div>
</header><!-- #masthead -->

<div id="content" class="site-content">
    <div class="nnc-container">

        <!-- trending-start -->
        <div class="nnc-trending-news nnc-clearblock">

            <?php

            if (get_theme_mod('rainbownews_top_bar_ticker') == 1 || get_theme_mod('rainbownews_activate_breadcrumb') == 1) :

                $news_ticker = get_theme_mod('rainbownews_new_ticker_layout', 'latest_post');

                if (is_home() || is_front_page()) {
                    if ($news_ticker == 'category_post') {
                        rainbownews_category_news();
                    } else {
                        if ($news_ticker == 'popular_post') {
                            rainbownews_latest_news();
                        } else {
                            rainbownews_trending_news();
                        }
                    }
                } else {
                    ?>
                    <div class="nnc-breadcrumbs nnc-trending-single">
                        <?php rainbownews_breadcrumbs(); ?>
                    </div>

                <?php } ?>

            <?php endif; ?>

            <?php if (get_theme_mod('rainbownews_activate_search') == 1) : ?>

                <div class="nnc-search nnc-clearblock">
                    <?php get_search_form(); ?>
                </div>

            <?php endif; ?>

        </div>
        <!-- trending-end -->

		    